@@ -228,7 +228,7 @@ class File {
 			$GLOBALS['am_error_log'][] = array('file_fail_remove');
 		}
 			
-		if (!unlink($directory . $md5_name)) {
+		if (!@unlink($directory . $md5_name)) {
 			$GLOBALS['am_error_log'][] = array('file_fail_remove');
 		}
 		
@@ -394,8 +394,8 @@ class File {
 	// checks if mime-type is ok
 	// Sebastian Oblom 22th September 2006
 	//
-	function checkMimeType()
-	{
+	function checkMimeType() {
+	
 		if (function_exists('finfo_open')) { // not tested but should work fine
 			$resource = finfo_open(FILEINFO_MIME);
 			$this->mime_type = finfo_file($resource, $this->file['tmp_name']);
@@ -407,7 +407,15 @@ class File {
 		else {
 			$this->mime_type = $this->file['type'];
 		}
-
+		
+		if (!empty($this->core_config_file['browser_path'])) {
+		    foreach($this->core_config_file['browser_path'] as $i):
+				if ($i['from'] == $this->mime_type) {
+				    $this->mime_type= $i['to'];
+				}
+			endforeach;
+		}
+		
 		foreach($this->core_config_file['mime'] as $mime) {
 			if ($mime['mime'] == $this->mime_type) {
 				return true;
@@ -480,7 +488,7 @@ class File {
 					$files[] = $temp;
 				}
 				else {
-					$temp['file_md5_name_view'] = $this->module_id . '-' . $temp['file_md5_name'];
+					$temp['file_md5_name_view'] = $this->module_id . '-' . $temp['file_md5_name'] . '-~-' . $temp['file_type'];
 					$files[] = $temp;
 				}
 				$result->moveNext();
@@ -531,6 +539,7 @@ class File {
 			if (isset($thumb_extension)) {
 				$directory .= "thumbs/"; 
 				$file_name = $temp['file_md5_name'] . $thumb_extension;
+				
 				if (is_file($directory . $file_name)) {
 					$temp['file_md5_name_view'] = $this->module_id . '-' . $temp['file_md5_name'] . '-' . $thumb_extension;
 				}
@@ -542,7 +551,9 @@ class File {
 				$temp['file_md5_name_view'] = $this->module_id . '-' . $temp['file_md5_name'];
 				
 			}
-
+			
+			$temp['file_md5_name_view'] .= "-" . $temp['file_type'];
+			
 			return $temp;	
 		}
 		else {
